package com.usky.dxtop.controller.web;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.core.domain.AjaxResult;
import com.usky.dxtop.model.Dept;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.model.StaffRadio;
import com.usky.dxtop.service.DeptService;
import com.usky.dxtop.service.StaffRadioService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.config.rabbitmq.face.FaceConsumeConfig;
import com.usky.dxtop.service.config.rabbitmq.group.GroupConsumeConfig;
import com.usky.dxtop.service.config.rabbitmq.profile.ProfileConsumeConfig;
import com.usky.dxtop.service.job.SmJob;
import com.usky.dxtop.service.vo.StaffRequest;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author yq
 * @date 2021/9/23 13:34
 */
@RestController
@RequestMapping("/dxtop/staff")
public class StaffController {

    @Autowired
    private StaffRadioService staffRadioService;

    @Autowired
    private StaffService staffService;
    @Autowired
    private DeptService deptService;
    @Autowired
    @Qualifier(ProfileConsumeConfig.TEMPLATE)
    private RabbitTemplate profileRabbitTemplate;


    @Autowired
    @Qualifier(FaceConsumeConfig.TEMPLATE)
    private RabbitTemplate faceRabbitTemplate;

    @Autowired
    @Qualifier(GroupConsumeConfig.TEMPLATE)
    private RabbitTemplate groupRabbitTemplate;

    @Autowired
    private SmJob smJob;

    /**
     *
     * @return
     */
    @RequestMapping("count")
    public AjaxResult count(){
        return AjaxResult.success(staffService.count());
    }


    /**
     * 批量新增
     * @param list
     * @return
     */
    @PostMapping()
    public AjaxResult addList(@RequestBody List<StaffRadio> list){
        staffRadioService.addList(list);
        return AjaxResult.success();
    }

    /**
     * 人员比例
     * @return
     */
    @GetMapping("staffRadio")
    public AjaxResult staffRadio(){
        return AjaxResult.success(staffRadioService.staffRadio());
    }

    @PostMapping("page")
    public AjaxResult page(@RequestBody StaffRequest staffRequest){
        return AjaxResult.success(staffService.page(staffRequest));
    }

    /**
     * 发送获取余额信息
     * @param card
     * @return
     */
    @GetMapping("cardBalance")
    public AjaxResult getCardBalance(@RequestParam String card){
        return AjaxResult.success(staffService.getBalance(card));
    }

    /**
     * 获取用户详情
     * @param id
     * @param phone
     * @param card
     * @return
     */
    @GetMapping("one")
    public AjaxResult getCardBalance(@RequestParam(required = false) String id,
                                     @RequestParam(required = false) String phone,
                                     @RequestParam(required = false) String card){
        return AjaxResult.success(staffService.one(id,phone,card));
    }

    @GetMapping("send")
    public String sendDeptAndStaff(@RequestParam Long staffId,
                                 @RequestParam  String card,
                                 @RequestParam  Integer type){
        Staff staff = staffService.getById(staffId);
        staff.setCardId(card);
        LambdaQueryWrapper<Dept> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(Dept::getId,staff.getDeptId());
        Dept dept = deptService.getOne(queryWrapper);
        smJob.deptSendMessage(dept);
        smJob.personSendMessage(staff,type);
        smJob.faceSendMessage(staff);
        return "sucess";
    }

}
